@@ -10,30 +10,30 @@ Mapillary Python SDK.
 
 For more information, please check out https://www.mapillary.com/developer/api-documentation/
 
-:copyright: (c) 2021 Facebook
-:license: MIT LICENSE
+- Copyright: (c) 2021 Facebook
+- License: MIT LICENSE
 """
 
-# Configs
+# Library imports
+import json
+
+import mercantile
+import shapely
+from geojson import Polygon
+
+# # Configs
 from mapillary.config.api.entities import Entities
 from mapillary.config.api.vector_tiles import VectorTiles
-
-# Exception Handling
-from mapillary.models.exceptions import InvalidImageKey
-from mapillary.utils.verify import (
-    image_check,
-    image_bbox_check,
-    sequence_bbox_check,
-    resolution_check,
-    valid_id,
-)
-
-# Client
-from mapillary.models.client import Client
+from mapillary.models.api.entities import EntityAdapter
 
 # # Adapters
 from mapillary.models.api.vector_tiles import VectorTilesAdapter
-from mapillary.models.api.entities import EntityAdapter
+
+# # Client
+from mapillary.models.client import Client
+
+# # Exception Handling
+from mapillary.models.exceptions import InvalidImageKeyError
 
 # # Class Representation
 from mapillary.models.geojson import GeoJSON
@@ -43,25 +43,30 @@ from mapillary.utils.filter import pipeline
 from mapillary.utils.format import (
     feature_to_geojson,
     merged_features_list_to_geojson,
-    geojson_to_polgyon,
+    geojson_to_polygon,
+)
+from mapillary.utils.verify import (
+    image_check,
+    image_bbox_check,
+    sequence_bbox_check,
+    resolution_check,
+    valid_id,
 )
-
-# Library imports
-import json
-import shapely
-import mercantile
-from geojson import Polygon
 from requests import HTTPError
-from vt2geojson.tools import vt_bytes_to_geojson
 from turfpy.measurement import bbox
+from vt2geojson.tools import vt_bytes_to_geojson
 
 
 def get_image_close_to_controller(
     longitude: float,
     latitude: float,
     kwargs: dict,
-) -> dict:
-    """Extracting the GeoJSON for the image data near the [longitude, latitude] coordinates
+) -> GeoJSON:
+    """
+    Extracting the GeoJSON for the image data near the [longitude, latitude] coordinates
+
+    :param kwargs: The kwargs for the filter
+    :type kwargs: dict
 
     :param longitude: The longitude
     :type longitude: float
@@ -160,23 +165,31 @@ def get_image_looking_at_controller(
     looker: dict,
     at: dict,
     filters: dict,
-) -> dict:
-    """Extracting the GeoJSON for the image data from a 'looker' and 'at' coordinate view
+) -> GeoJSON:
+    """
+    Extracting the GeoJSON for the image data from a 'looker' and 'at' coordinate view
+
+    :param filters: Filters to pass the data through
+    :type filters: dict
 
     :param looker: The dictionary of coordinates of the position of the looking from
-    coordinates, in the format,
-        >>> looker = {
-        >>>     'lng': <longitudinal parameter>
-        >>>     'lat': <latitude parameters>
-        >>> }
+        coordinates. Format::
+
+            >>> {
+            >>>     'lng': 'longitude',
+            >>>     'lat': 'latitude'
+            >>> }
+
     :type looker: dict
 
     :param at: The dict of coordinates of the position of the looking at
-    coordinates, in the format,
-        >>> at = {
-        >>>     'lng': <longitudinal parameter>
-        >>>     'lat': <latitude parameters>
-        >>> }
+        coordinates. Format::
+
+            >>> {
+            >>>     'lng': 'longitude',
+            >>>     'lat': 'latitude'
+            >>> }
+
     :type at: dict
 
     :param filters.min_captured_at: The minimum date to filter till
@@ -207,7 +220,7 @@ def get_image_looking_at_controller(
         longitude=looker["lng"], latitude=looker["lat"], kwargs=filters
     ).to_dict()
 
-    if looker["features"] == []:
+    if not looker["features"]:
         return GeoJSON(geojson=looker)
 
     # Filter the unfiltered results by the given filters
@@ -251,15 +264,18 @@ def get_image_looking_at_controller(
     )
 
 
-def get_image_thumbnail_controller(image_id, resolution: int) -> str:
-    """This controller holds the business logic for retrieving
+def get_image_thumbnail_controller(image_id: str, resolution: int) -> str:
+    """
+    This controller holds the business logic for retrieving
     an image thumbnail with a specific resolution (256, 1024, or 2048)
     using an image ID/key
 
     :param image_id: Image key as the argument
+    :type image_id: str
 
     :param resolution: Option for the thumbnail size, with available resolutions:
-    256, 1024, and 2048
+        256, 1024, and 2048
+    :type resolution: int
 
     :return: A URL for the thumbnail
     :rtype: str
@@ -272,25 +288,38 @@ def get_image_thumbnail_controller(image_id, resolution: int) -> str:
         res = Client().get(Entities.get_image(image_id, [f"thumb_{resolution}_url"]))
     except HTTPError:
         # If given ID is an invalid image ID, let the user know
-        raise InvalidImageKey(image_id)
+        raise InvalidImageKeyError(image_id)
 
     return json.loads(res.content.decode("utf-8"))[f"thumb_{resolution}_url"]
 
 
 def get_images_in_bbox_controller(
-    bbox: dict, layer: str, zoom: int, filters: dict
+    bounding_box: dict, layer: str, zoom: int, filters: dict
 ) -> str:
-    """For getting a complete list of images that lie within a bounding box,
-     that can be filered via the filters argument
+    """
+    For getting a complete list of images that lie within a bounding box,
+    that can be filtered via the filters argument
 
-    :param bbox: A bounding box representation
-    example: {
-        'west': 'BOUNDARY_FROM_WEST',
-        'south': 'BOUNDARY_FROM_SOUTH',
-        'east': 'BOUNDARY_FROM_EAST',
-        'north': 'BOUNDARY_FROM_NORTH'
-    }
-    :type bbox: dict
+    :param bounding_box: A bounding box representation
+        Example::
+
+            >>> {
+            ...     'west': 'BOUNDARY_FROM_WEST',
+            ...     'south': 'BOUNDARY_FROM_SOUTH',
+            ...     'east': 'BOUNDARY_FROM_EAST',
+            ...     'north': 'BOUNDARY_FROM_NORTH'
+            ... }
+
+    :type bounding_box: dict
+
+    :param zoom: The zoom level
+    :param zoom: int
+
+    :param layer: Either 'image', 'sequence', 'overview'
+    :type layer: str
+
+    :param filters: Filters to pass the data through
+    :type filters: dict
 
     :param filters.max_captured_at: The max date that can be filtered upto
     :type filters.max_captured_at: str
@@ -310,15 +339,15 @@ def get_images_in_bbox_controller(
     :param filters.sequence_id:
     :type filters.sequence_id: str
 
-    '''
-    :raise InvalidKwargError: Raised when a function is called with the invalid keyword argument(s)
-    that do not belong to the requested API end call
-    '''
+    :raises InvalidKwargError: Raised when a function is called with the invalid keyword argument(s)
+        that do not belong to the requested API end call
 
     :return: GeoJSON
     :rtype: str
 
-    Reference: https://www.mapillary.com/developer/api-documentation/#coverage-tiles
+    Reference,
+
+    - https://www.mapillary.com/developer/api-documentation/#coverage-tiles
     """
 
     # Check if the given filters are valid ones
@@ -336,10 +365,10 @@ def get_images_in_bbox_controller(
     # A list of tiles that are either confined within or intersect with the bbox
     tiles = list(
         mercantile.tiles(
-            west=bbox["west"],
-            south=bbox["south"],
-            east=bbox["east"],
-            north=bbox["north"],
+            west=bounding_box["west"],
+            south=bounding_box["south"],
+            east=bounding_box["east"],
+            north=bounding_box["north"],
             zooms=zoom,
         )
     )
@@ -364,7 +393,7 @@ def get_images_in_bbox_controller(
             pipeline(
                 data=geojson,
                 components=[
-                    {"filter": "features_in_bounding_box", "bbox": bbox}
+                    {"filter": "features_in_bounding_box", "bbox": bounding_box}
                     if layer == "image"
                     else {},
                     {
@@ -406,6 +435,7 @@ def get_image_from_key_controller(key: int, fields: list) -> str:
     """
     A controller for getting properties of a certain image given the image key and
     the list of fields/properties to be returned
+
     :param key: The image key
     :type key: int
 
@@ -416,22 +446,31 @@ def get_image_from_key_controller(key: int, fields: list) -> str:
     :rtype: str
     """
 
-    valid_id(id=key, image=True)
+    valid_id(identity=key, image=True)
+
+    # ? 'merged_features_list_to_geojson' takes list, 'feature_to_geojson' returns dict
     return merged_features_list_to_geojson(
-        feature_to_geojson(EntityAdapter().fetch_image(image_id=key, fields=fields))
+        features_list=feature_to_geojson(
+            json_data=EntityAdapter().fetch_image(image_id=key, fields=fields)
+        )
     )
 
 
 def geojson_features_controller(
     geojson: dict, is_image: bool = True, filters: dict = None
-) -> dict:
-    """For extracting images that lie within a GeoJSON and merges the results of the found
+) -> GeoJSON:
+    """
+    For extracting images that lie within a GeoJSON and merges the results of the found
     GeoJSON(s) into a single object - by merging all the features into one feature list.
 
     :param geojson: The geojson to act as the query extent
     :type geojson: dict
 
-    :param **filters: Different filters that may be applied to the output, defaults to {}
+    :param is_image: Is the feature extraction for images? True for images, False for map features
+        Defaults to True
+    :type is_image: bool
+
+    :param filters: Different filters that may be applied to the output, defaults to {}
     :type filters: dict (kwargs)
 
     :param filters.zoom: The zoom level to obtain vector tiles for, defaults to 14
@@ -444,8 +483,8 @@ def geojson_features_controller(
     :type filters.min_captured_at: str
 
     :param filters.image_type: The tile image_type to be obtained, either as 'flat', 'pano'
-    (panoramic), or 'all'. See https://www.mapillary.com/developer/api-documentation/ under
-    'image_type Tiles' for more information
+        (panoramic), or 'all'. See https://www.mapillary.com/developer/api-documentation/ under
+        'image_type Tiles' for more information
     :type filters.image_type: str
 
     :param filters.compass_angle: The compass angle of the image
@@ -458,17 +497,15 @@ def geojson_features_controller(
     :type filters.organization_id: str
 
     :param filters.layer: The specified image layer, either 'overview', 'sequence', 'image'
-    if is_image is True, defaults to 'image'
+        if is_image is True, defaults to 'image'
     :type filters.layer: str
 
     :param filters.feature_type: The specified map features, either 'point' or 'traffic_signs'
-    if is_image is False, defaults to 'point'
+        if is_image is False, defaults to 'point'
     :type filters.feature_type: str
 
-    '''
-    :raise InvalidKwargError: Raised when a function is called with the invalid keyword argument(s)
-    that do not belong to the requested API end call
-    '''
+    :raises InvalidKwargError: Raised when a function is called with the invalid keyword argument(s)
+        that do not belong to the requested API end call
 
     :return: A feature collection as a GeoJSON
     :rtype: dict
@@ -478,7 +515,7 @@ def geojson_features_controller(
     image_bbox_check(filters)
 
     # Extracting polygon from geojson, converting to dict
-    polygon = geojson_to_polgyon(geojson).to_dict()
+    polygon = geojson_to_polygon(geojson).to_dict()
 
     # Generating a coordinates list to extract from polygon
     coordinates_list = []
@@ -488,23 +525,19 @@ def geojson_features_controller(
 
         # Going through the coordinate's nested list
         for coordinates in feature["geometry"]["coordinates"][0]:
-
             # Appending a tuple of coordinates
             coordinates_list.append((coordinates[0], coordinates[1]))
 
     # Sending coordinates_list a input to form a Polygon
-    polygon = Polygon([coordinates_list])
+    polygon = Polygon(coordinates_list)
 
-    # Getting the boundary paramters from polygon
+    # Getting the boundary parameters from polygon
     boundary = shapely.geometry.shape(polygon)
 
-    # To hold the result
-    layers = None
-
     if is_image:
         # Get a GeoJSON with features from tiles originating from coordinates
         # at specified zoom level
-        layers: GeoJSON = (
+        layers: dict = (
             VectorTilesAdapter()
             .fetch_layers(
                 # Sending coordinates for all the points within input geojson
@@ -518,7 +551,7 @@ def geojson_features_controller(
         )
     else:
         # Get all the map features within the boundary box for the polygon
-        layers: GeoJSON = (
+        layers: dict = (
             VectorTilesAdapter()
             .fetch_map_features(
                 # Sending coordinates for all the points within input geojson
@@ -539,7 +572,7 @@ def geojson_features_controller(
         geojson=json.loads(
             # Convert feature list to GeoJSON
             merged_features_list_to_geojson(
-                # Execture pipeline for filters
+                # Execute pipeline for filters
                 pipeline(
                     # Sending layers as input
                     data=layers,
@@ -591,37 +624,43 @@ def geojson_features_controller(
 
 def shape_features_controller(
     shape, is_image: bool = True, filters: dict = None
-) -> dict:
-    """For extracting images that lie within a shape, merging the results of the found features
+) -> GeoJSON:
+    """
+    For extracting images that lie within a shape, merging the results of the found features
     into a single object - by merging all the features into one list in a feature collection.
 
-    The shape format is as follows,
-    'shape = {
-        "type": "FeatureCollection",
-        "features": [
-            {
-                "type": "Feature",
-                "properties": {},
-                "geometry": {
-                    "type": "Polygon",
-                    "coordinates": [
-                        [
-                            [
-                                7.2564697265625,
-                                43.69716905314008
-                            ],
-                            ...
-                        ]
-                    ]
-                }
-            }
-        ]
-    }'
+    The shape format is as follows::
+
+        >>> {
+        ...     "type": "FeatureCollection",
+        ...     "features": [
+        ...         {
+        ...             "type": "Feature",
+        ...             "properties": {},
+        ...             "geometry": {
+        ...                 "type": "Polygon",
+        ...                 "coordinates": [
+        ...                     [
+        ...                        [
+        ...                              7.2564697265625,
+        ...                             43.69716905314008
+        ...                         ],
+        ...                         ...
+        ...                     ]
+        ...                 ]
+        ...             }
+        ...         }
+        ...     ]
+        ... }
 
     :param shape: A shape that describes features, formatted as a geojson
     :type shape: dict
 
-    :param **filters: Different filters that may be applied to the output, defaults to {}
+    :param is_image: Is the feature extraction for images? True for images, False for map features
+        Defaults to True
+    :type is_image: bool
+
+    :param filters: Different filters that may be applied to the output, defaults to {}
     :type filters: dict (kwargs)
 
     :param filters.max_captured_at: The max date. Format from 'YYYY', to 'YYYY-MM-DDTHH:MM:SS'
@@ -631,8 +670,8 @@ def shape_features_controller(
     :type filters.min_captured_at: str
 
     :param filters.image_type: The tile image_type to be obtained, either as 'flat', 'pano'
-    (panoramic), or 'all'. See https://www.mapillary.com/developer/api-documentation/ under
-    'image_type Tiles' for more information
+        (panoramic), or 'all'. See https://www.mapillary.com/developer/api-documentation/ under
+        'image_type Tiles' for more information
     :type filters.image_type: str
 
     :param filters.compass_angle: The compass angle of the image
@@ -645,17 +684,15 @@ def shape_features_controller(
     :type filters.organization_id: str
 
     :param filters.layer: The specified image layer, either 'overview', 'sequence', 'image'
-    if is_image is True, defaults to 'image'
+        if is_image is True, defaults to 'image'
     :type filters.layer: str
 
     :param filters.feature_type: The specified map features, either 'point' or 'traffic_signs'
-    if is_image is False, defaults to 'point'
+        if is_image is False, defaults to 'point'
     :type filters.feature_type: str
 
-    '''
-    :raise InvalidKwargError: Raised when a function is called with the invalid keyword argument(s)
-    that do not belong to the requested API end call
-    '''
+    :raises InvalidKwargError: Raised when a function is called with the invalid keyword argument(s)
+        that do not belong to the requested API end call
 
     :return: A feature collection as a GeoJSON
     :rtype: dict
@@ -671,22 +708,18 @@ def shape_features_controller(
 
         # Going through the coordinate's nested list
         for coordinates in feature["geometry"]["coordinates"][0]:
-
             # Appending a tuple of coordinates
             coordinates_list.append((coordinates[0], coordinates[1]))
 
     # Sending coordinates_list a input to form a Polygon
-    polygon = Polygon([coordinates_list])
+    polygon = Polygon(coordinates_list)
 
-    # Getting the boundary paramters from polygon
+    # Getting the boundary parameters from polygon
     boundary = shapely.geometry.shape(polygon)
 
-    # To store the result
-    output = None
-
     if is_image:
         # Get all the map features within the boundary box for the polygon
-        output: GeoJSON = (
+        output: dict = (
             VectorTilesAdapter()
             .fetch_layers(
                 # Sending coordinates for all the points within input geojson
@@ -700,7 +733,7 @@ def shape_features_controller(
         )
     else:
         # Get all the map features within the boundary box for the polygon
-        output: GeoJSON = (
+        output: dict = (
             VectorTilesAdapter()
             .fetch_map_features(
                 # Sending coordinates for all the points within input geojson
@@ -721,7 +754,7 @@ def shape_features_controller(
         geojson=json.loads(
             # Convert feature list to GeoJSON
             merged_features_list_to_geojson(
-                # Execture pipeline for filters
+                # Execute pipeline for filters
                 pipeline(
                     # Sending layers as input
                     data=output,
