@@ -195,7 +195,7 @@ def get_image_looking_at(
 
 
 @auth()
-def get_detections_with_image_id(image_id: int, fields: list = None):
+def get_detections_with_image_id(image_id: int, fields: list = []):
     """
     Extracting all the detections within an image using an image key
 
@@ -808,9 +808,9 @@ def feature_from_key(key: str, fields: list = []) -> str:
         Fields::
 
                 1. first_seen_at - timestamp, timestamp of the least recent
-                detection contributing to this feature
+                    detection contributing to this feature
                 2. last_seen_at - timestamp, timestamp of the most recent
-                detection contributing to this feature
+                    detection contributing to this feature
                 3. object_value - string, what kind of map feature it is
                 4. object_type - string, either a traffic_sign or point
                 5. geometry - GeoJSON Point geometry
