@@ -3,21 +3,22 @@
 
 """
 mapillary.utils.time
-~~~~~~~~~~~~~~~~~~~~
+====================
 
 This module contains the time utilies for the UNIX epoch seconds, the time and the date range, and
 the date filtering logic.
 
-:copyright: (c) 2021 Facebook
-:license: MIT LICENSE
+- Copyright: (c) 2021 Facebook
+- License: MIT LICENSE
 """
 
 # Package imports
 import datetime
 
 
-def date_to_unix_timestamp(date: str):
-    """A utility function that converts the given date
+def date_to_unix_timestamp(date: str) -> int:
+    """
+    A utility function that converts the given date
     into its UNIX epoch timestamp equivalent. It accepts the formats, ranging from
     YYYY-MM-DDTHH:MM:SS, to simply YYYY, and a permutation of the fields in between as well
 
@@ -26,10 +27,14 @@ def date_to_unix_timestamp(date: str):
     :param date: The date to get the UNIX timestamp epoch of
     :type date: str
 
+    :return: The UNIX timestamp equivalent of the input date
+    :rtype: int
+
     Usage::
+
         >>> from utils.time_utils import date_to_unix_timestamp
         >>> date_to_unix_timestamp('2020-10-23')
-        "1603393200"
+        ... "1603393200"
     """
 
     # Returns the epoch current timestamp in milliseconds
